# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.0.0

import enum

import winrt.system
from winrt._winrt_windows_applicationmodel_voicecommands import (
    VoiceCommand,
    VoiceCommandCompletedEventArgs,
    VoiceCommandConfirmationResult,
    VoiceCommandContentTile,
    VoiceCommandDefinition,
    VoiceCommandDefinitionManager,
    VoiceCommandDisambiguationResult,
    VoiceCommandResponse,
    VoiceCommandServiceConnection,
    VoiceCommandUserMessage,
)

__all__ = [
    "VoiceCommandCompletionReason",
    "VoiceCommandContentTileType",
    "VoiceCommand",
    "VoiceCommandCompletedEventArgs",
    "VoiceCommandConfirmationResult",
    "VoiceCommandContentTile",
    "VoiceCommandDefinition",
    "VoiceCommandDefinitionManager",
    "VoiceCommandDisambiguationResult",
    "VoiceCommandResponse",
    "VoiceCommandServiceConnection",
    "VoiceCommandUserMessage",
]

class VoiceCommandCompletionReason(enum.IntEnum):
    UNKNOWN = 0
    COMMUNICATION_FAILED = 1
    RESOURCE_LIMITS_EXCEEDED = 2
    CANCELED = 3
    TIMEOUT_EXCEEDED = 4
    APP_LAUNCHED = 5
    COMPLETED = 6

class VoiceCommandContentTileType(enum.IntEnum):
    TITLE_ONLY = 0
    TITLE_WITH_TEXT = 1
    TITLE_WITH68X68_ICON = 2
    TITLE_WITH68X68_ICON_AND_TEXT = 3
    TITLE_WITH68X92_ICON = 4
    TITLE_WITH68X92_ICON_AND_TEXT = 5
    TITLE_WITH280X140_ICON = 6
    TITLE_WITH280X140_ICON_AND_TEXT = 7

